package org.dromara.ems.base.service;

import org.dromara.ems.base.domain.EmsBaseMonitorWorkUnit;

import java.util.List;

/**
 * 统计计量信息Service接口
 * 
 * @author Yinq
 * @date 2024-05-09
 */
public interface IEmsBaseMonitorWorkUnitService 
{
    /**
     * 查询统计计量信息
     * 
     * @param objId 统计计量信息主键
     * @return 统计计量信息
     */
    public EmsBaseMonitorWorkUnit selectEmsBaseMonitorWorkUnitByObjId(Long objId);

    /**
     * 查询统计计量信息列表
     * 
     * @param emsBaseMonitorWorkUnit 统计计量信息
     * @return 统计计量信息集合
     */
    public List<EmsBaseMonitorWorkUnit> selectEmsBaseMonitorWorkUnitList(EmsBaseMonitorWorkUnit emsBaseMonitorWorkUnit);

    /**
     * 新增统计计量信息
     * 
     * @param emsBaseMonitorWorkUnit 统计计量信息
     * @return 结果
     */
    public int insertEmsBaseMonitorWorkUnit(EmsBaseMonitorWorkUnit emsBaseMonitorWorkUnit);

    /**
     * 修改统计计量信息
     * 
     * @param emsBaseMonitorWorkUnit 统计计量信息
     * @return 结果
     */
    public int updateEmsBaseMonitorWorkUnit(EmsBaseMonitorWorkUnit emsBaseMonitorWorkUnit);

    /**
     * 批量删除统计计量信息
     * 
     * @param objIds 需要删除的统计计量信息主键集合
     * @return 结果
     */
    public int deleteEmsBaseMonitorWorkUnitByObjIds(Long[] objIds);

    /**
     * 删除统计计量信息信息
     * 
     * @param objId 统计计量信息主键
     * @return 结果
     */
    public int deleteEmsBaseMonitorWorkUnitByObjId(Long objId);
}
